@@ -39,15 +39,19 @@ abstract methods :meth:`~ae.gui_app.MainAppBase.init_app` and
 
     from ae.gui_help import HelpAppBase
 
-    class MyFrameworkAppBase(HelpAppBase):
-        def init_app(self, framework_app_class = None):
+    class MyMainApp(HelpAppBase):
+        def init_app(self, framework_app_class=None):
+            self.framework_app = framework_app_class()
             ...
+            return self.framework_app.run, self.framework_app.stop
+
         def ensure_top_most_z_index(self, widget):
+            framework_method_to_push_widget_to_top_most(widget)
             ...
 
 For to activate the help mode the widget
 for to display the help texts have to be assigned to
-the attribute :attr:`~HelpAppBase.ae_help_layout::
+the attribute :attr:`~HelpAppBase.ae_help_layout`::
 
     main_app.ae_help_layout = HelpScreenContainerOrWindow()
 
@@ -195,7 +199,8 @@ doc string of the :mod:`ae.i18n` module.
 
 A more complex example app demonstrating the features
 of this context help system can be found in the
-repository <https://gitlab.com/ae-group/kivy_lisz>`__ .
+repository of the
+`kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`_.
 
 """
 from abc import abstractmethod, ABC
@@ -206,7 +211,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, id_of_flow, MainAppBase                    # type: ignore
 
 
-__version__ = '0.0.4'
+__version__ = '0.1.5'
 
 
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )  #: tuple of flow ids never search/show help text for
